@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_SYS_MMAN_H
 #include <sys/mman.h>
+#endif
 #include <unistd.h>
 #include <dirent.h>
 #include <fcntl.h>
@@ -53,14 +55,14 @@ streams_match (GMimeStream **streams, const char *filename)
 	size_t nread, size;
 	ssize_t n;
 	
-	v(fprintf (stdout, "Matching original stream (" OFF_T " -> " OFF_T ") with %s (" OFF_T ", " OFF_T ")... ",
+	v(fprintf (stdout, "Matching original stream (%" G_GINT64_FORMAT " -> %" G_GINT64_FORMAT ") with %s (%" G_GINT64_FORMAT ", %" G_GINT64_FORMAT ")... ",
 		   streams[0]->position, streams[0]->bound_end, filename,
 		   streams[1]->position, streams[1]->bound_end));
 	
 	if (streams[0]->bound_end != -1) {
 		totalsize = streams[0]->bound_end - streams[0]->position;
 	} else if ((n = g_mime_stream_length (streams[0])) == -1) {
-		sprintf (errstr, "Error: Unable to get length of original stream\n");
+		sprintf (errstr, "Error: Unable to get length of original stream: %s\n", g_strerror (errno));
 		goto fail;
 	} else if (n < (streams[0]->position - streams[0]->bound_start)) {
 		sprintf (errstr, "Error: Overflow on original stream?\n");
@@ -77,19 +79,19 @@ streams_match (GMimeStream **streams, const char *filename)
 		nread = 0;
 		totalread += n;
 		
-		d(fprintf (stderr, "read " SIZE_T " bytes from stream[0]\n", size));
+		d(fprintf (stderr, "read %" G_GSIZE_FORMAT " bytes from stream[0]\n", size));
 		
 		do {
 			if ((n = g_mime_stream_read (streams[1], dbuf + nread, size - nread)) <= 0) {
-				d(fprintf (stderr, "stream[1] read() returned " SSIZE_T ", EOF\n", n));
+				d(fprintf (stderr, "stream[1] read() returned %" G_GSSIZE_FORMAT ", EOF\n", n));
 				break;
 			}
-			d(fprintf (stderr, "read " SSIZE_T " bytes from stream[1]\n", n));
+			d(fprintf (stderr, "read %" G_GSSIZE_FORMAT " bytes from stream[1]\n", n));
 			nread += n;
 		} while (nread < size);
 		
 		if (nread < size) {
-			sprintf (errstr, "Error: `%s' appears to be truncated, short %u+ bytes\n",
+			sprintf (errstr, "Error: `%s' appears to be truncated, short %" G_GSIZE_FORMAT "+ bytes\n",
 				 filename, size - nread);
 			goto fail;
 		}
@@ -98,7 +100,7 @@ streams_match (GMimeStream **streams, const char *filename)
 			sprintf (errstr, "Error: `%s': content does not match\n", filename);
 			goto fail;
 		} else {
-			d(fprintf (stderr, "%u bytes identical\n", size));
+			d(fprintf (stderr, "%" G_GSIZE_FORMAT " bytes identical\n", size));
 		}
 	}
 	
@@ -130,9 +132,12 @@ test_stream_gets (GMimeStream *stream, const char *filename)
 	char sbuf[100], rbuf[100];
 	ssize_t slen;
 	FILE *fp;
-	
-	if (!(fp = fopen (filename, "r+")))
-		throw (exception_new ("could not open `%s': %s", filename, strerror (errno)));
+
+	/* '0x1a' character is treated as EOF (Ctrl+Z) on Windows if file is opened in text mode,
+	 *  thus it's opened in binary mode.
+	 */
+	if (!(fp = fopen (filename, "r+b")))
+		throw (exception_new ("could not open `%s': %s", filename, g_strerror (errno)));
 	
 	while (!g_mime_stream_eos (stream)) {
 		rbuf[0] = '\0';
@@ -146,8 +151,8 @@ test_stream_gets (GMimeStream *stream, const char *filename)
 	fclose (fp);
 	
 	if (strcmp (sbuf, rbuf) != 0) {
-		v(fprintf (stderr, "\tstream: \"%s\" (" SIZE_T ")\n", sbuf, strlen (sbuf)));
-		v(fprintf (stderr, "\treal:   \"%s\" (" SIZE_T ")\n", rbuf, strlen (rbuf)));
+		v(fprintf (stderr, "\tstream: \"%s\" (%" G_GSIZE_FORMAT ")\n", sbuf, strlen (sbuf)));
+		v(fprintf (stderr, "\treal:   \"%s\" (%" G_GSIZE_FORMAT ")\n", rbuf, strlen (rbuf)));
 		throw (exception_new ("streams did not match"));
 	}
 }
@@ -155,7 +160,7 @@ test_stream_gets (GMimeStream *stream, const char *filename)
 static void
 test_stream_buffer_gets (const char *filename)
 {
-	GMimeStream *stream, *buffered;
+	GMimeStream *stream, *buffered = NULL;
 	int fd;
 	
 	if ((fd = open (filename, O_RDONLY)) == -1) {
@@ -204,7 +209,7 @@ test_stream_mem (const char *filename)
 	int fd;
 	
 	if ((fd = open (filename, O_RDONLY)) == -1) {
-		v(fprintf (stderr, "failed to open %s", filename));
+		v(fprintf (stderr, "failed to open %s: %s\n", filename, g_strerror (errno)));
 		return;
 	}
 	
@@ -240,7 +245,7 @@ test_stream_mem (const char *filename)
 
 
 static gboolean
-check_stream_fs (const char *input, const char *output, const char *filename, off_t start, off_t end)
+check_stream_fs (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
 	GMimeStream *streams[2], *stream;
 	Exception *ex = NULL;
@@ -273,7 +278,7 @@ check_stream_fs (const char *input, const char *output, const char *filename, of
 }
 
 static gboolean
-check_stream_file (const char *input, const char *output, const char *filename, off_t start, off_t end)
+check_stream_file (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
 	GMimeStream *streams[2], *stream;
 	Exception *ex = NULL;
@@ -305,8 +310,9 @@ check_stream_file (const char *input, const char *output, const char *filename,
 	return TRUE;
 }
 
+#ifdef HAVE_SYS_MMAN_H
 static gboolean
-check_stream_mmap (const char *input, const char *output, const char *filename, off_t start, off_t end)
+check_stream_mmap (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
 	GMimeStream *streams[2], *stream;
 	Exception *ex = NULL;
@@ -337,9 +343,10 @@ check_stream_mmap (const char *input, const char *output, const char *filename,
 	
 	return TRUE;
 }
+#endif
 
 static gboolean
-check_stream_buffer_block (const char *input, const char *output, const char *filename, off_t start, off_t end)
+check_stream_buffer_block (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
 	GMimeStream *streams[2], *stream;
 	Exception *ex = NULL;
@@ -374,7 +381,7 @@ check_stream_buffer_block (const char *input, const char *output, const char *fi
 }
 
 static gboolean
-check_stream_buffer_cache (const char *input, const char *output, const char *filename, off_t start, off_t end)
+check_stream_buffer_cache (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
 	GMimeStream *streams[2], *stream;
 	Exception *ex = NULL;
@@ -409,7 +416,7 @@ check_stream_buffer_cache (const char *input, const char *output, const char *fi
 }
 
 
-typedef gboolean (* checkFunc) (const char *, const char *, const char *, off_t, off_t);
+typedef gboolean (* checkFunc) (const char *, const char *, const char *, gint64, gint64);
 
 static struct {
 	const char *what;
@@ -417,7 +424,9 @@ static struct {
 } checks[] = {
 	{ "GMimeStreamFs",                  check_stream_fs           },
 	{ "GMimeStreamFile",                check_stream_file         },
+#ifdef HAVE_SYS_MMAN_H
 	{ "GMimeStreamMmap",                check_stream_mmap         },
+#endif
 	{ "GMimeStreamBuffer (block mode)", check_stream_buffer_block },
 	{ "GMimeStreamBuffer (cache mode)", check_stream_buffer_cache },
 };
@@ -427,7 +436,7 @@ test_streams (DIR *dir, const char *datadir, const char *filename)
 {
 	char inpath[256], outpath[256], *p, *q, *o;
 	struct dirent *dent;
-	off_t start, end;
+	gint64 start, end;
 	size_t n;
 	guint i;
 	
@@ -446,7 +455,7 @@ test_streams (DIR *dir, const char *datadir, const char *filename)
 	n = strlen (filename);
 	
 	while ((dent = readdir (dir))) {
-		if (strncmp (dent->d_name, filename, n) != 0 || dent->d_name[n] != ':')
+		if (strncmp (dent->d_name, filename, n) != 0 || dent->d_name[n] != '_')
 			continue;
 		
 		p = dent->d_name + n + 1;
@@ -480,7 +489,7 @@ test_streams (DIR *dir, const char *datadir, const char *filename)
 }
 
 
-static void
+static size_t
 gen_random_stream (GMimeStream *stream)
 {
 	size_t nwritten, buflen, total = 0, size, i;
@@ -489,7 +498,7 @@ gen_random_stream (GMimeStream *stream)
 	
 	/* read between 4k and 14k bytes */
 	size = 4096 + (size_t) (10240.0 * (rand () / (RAND_MAX + 1.0)));
-	v(fprintf (stdout, "Generating " SIZE_T " bytes of random data... ", size));
+	v(fprintf (stdout, "Generating %" G_GSIZE_FORMAT " bytes of random data... ", size));
 	v(fflush (stdout));
 	
 	while (total < size) {
@@ -513,6 +522,8 @@ gen_random_stream (GMimeStream *stream)
 	g_mime_stream_reset (stream);
 	
 	v(fputs ("done\n", stdout));
+
+	return size;
 }
 
 static int
@@ -520,9 +531,7 @@ gen_test_data (const char *datadir, char **stream_name)
 {
 	GMimeStream *istream, *ostream, *stream;
 	char input[256], output[256], *name, *p;
-	off_t start, end;
-	struct stat st;
-	size_t len;
+	gint64 start, end, len, size;
 	int fd, i;
 	
 	srand (time (NULL));
@@ -541,36 +550,30 @@ gen_test_data (const char *datadir, char **stream_name)
 	*name++ = G_DIR_SEPARATOR;
 	strcpy (name, "streamXXXXXX");
 	
-	if ((fd = mkstemp (input)) == -1)
+	if ((fd = g_mkstemp (input)) == -1)
 		return -1;
 	
 	*stream_name = g_strdup (name);
 	
 	*p++ = G_DIR_SEPARATOR;
 	p = g_stpcpy (p, name);
-	*p++ = ':';
+	*p++ = '_';
 	
 	istream = g_mime_stream_fs_new (fd);
-	gen_random_stream (istream);
-	
-	if (stat (input, &st) == -1 || !S_ISREG (st.st_mode)) {
-		g_object_unref (istream);
-		unlink (input);
-		return -1;
-	}
+	size = gen_random_stream (istream);
 	
 	for (i = 0; i < 64; i++) {
 	retry:
-		start = (off_t) (st.st_size * (rand () / (RAND_MAX + 1.0)));
-		len = (size_t) (st.st_size * (rand () / (RAND_MAX + 1.0)));
-		if (start + len > st.st_size) {
-			len = st.st_size - start;
+		start = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
+		len = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
+		if (start + len > size) {
+			len = size - start;
 			end = -1;
 		} else {
 			end = start + len;
 		}
 		
-		sprintf (p, OFF_T "," OFF_T, start, end);
+		sprintf (p, "%" G_GINT64_FORMAT ",%" G_GINT64_FORMAT, start, end);
 		
 		if ((fd = open (output, O_CREAT | O_EXCL | O_TRUNC | O_WRONLY, 0666)) == -1)
 			goto retry;
